@@ -67,33 +67,27 @@ class Task:
 
     @abstractmethod
     def get_prior(self) -> Callable:
-        """Get function returning parameters from prior
-        """
+        """Get function returning parameters from prior"""
         raise NotImplementedError
 
     def get_prior_dist(self) -> torch.distributions.Distribution:
-        """Get prior distribution
-        """
+        """Get prior distribution"""
         return self.prior_dist
 
     def get_prior_params(self) -> Dict[str, torch.Tensor]:
-        """Get parameters of prior distribution
-        """
+        """Get parameters of prior distribution"""
         return self.prior_params
 
     def get_labels_data(self) -> List[str]:
-        """Get list containing parameter labels
-        """
+        """Get list containing parameter labels"""
         return [f"data_{i+1}" for i in range(self.dim_data)]
 
     def get_labels_parameters(self) -> List[str]:
-        """Get list containing parameter labels
-        """
+        """Get list containing parameter labels"""
         return [f"parameter_{i+1}" for i in range(self.dim_parameters)]
 
     def get_observation(self, num_observation: int) -> torch.Tensor:
-        """Get observed data for a given observation number
-        """
+        """Get observed data for a given observation number"""
         path = (
             self.path
             / "files"
@@ -103,8 +97,7 @@ class Task:
         return get_tensor_from_csv(path)
 
     def get_reference_posterior_samples(self, num_observation: int) -> torch.Tensor:
-        """Get reference posterior samples for a given observation number
-        """
+        """Get reference posterior samples for a given observation number"""
         path = (
             self.path
             / "files"
@@ -115,13 +108,11 @@ class Task:
 
     @abstractmethod
     def get_simulator(self) -> Callable:
-        """Get function returning parameters from prior
-        """
+        """Get function returning parameters from prior"""
         raise NotImplementedError
 
     def get_true_parameters(self, num_observation: int) -> torch.Tensor:
-        """Get true parameters (parameters that generated the data) for a given observation number
-        """
+        """Get true parameters (parameters that generated the data) for a given observation number"""
         path = (
             self.path
             / "files"
@@ -131,13 +122,11 @@ class Task:
         return get_tensor_from_csv(path)
 
     def save_data(self, path: Union[str, Path], data: torch.Tensor):
-        """Save data to a given path
-        """
+        """Save data to a given path"""
         save_tensor_to_csv(path, data, self.get_labels_data())
 
     def save_parameters(self, path: Union[str, Path], parameters: torch.Tensor):
-        """Save parameters to a given path
-        """
+        """Save parameters to a given path"""
         save_tensor_to_csv(path, parameters, self.get_labels_parameters())
 
     def flatten_data(self, data: torch.Tensor) -> torch.Tensor:
@@ -188,7 +177,9 @@ class Task:
         )
 
         log_prob_fn, _ = get_log_prob_fn(
-            conditioned_model, implementation=implementation, **kwargs,
+            conditioned_model,
+            implementation=implementation,
+            **kwargs,
         )
 
         def log_prob_pyro(parameters):
@@ -203,7 +194,7 @@ class Task:
                     log_probs.append(
                         log_prob_fn({"parameters": parameters[i, :].reshape(1, -1)})
                     )
-                return torch.stack(log_probs)
+                return torch.cat(log_probs)
 
         def log_prob_experimental(parameters):
             return log_prob_fn({"parameters": parameters})
@@ -234,7 +225,7 @@ class Task:
             kwargs: Passed to `sbibm.utils.pyro.get_log_prob_grad_fn`
 
         Returns:
-            `log_prob_grad_fn` that returns gradients as `batch_size` x 
+            `log_prob_grad_fn` that returns gradients as `batch_size` x
             `dim_parameter`
         """
         assert not (num_observation is None and observation is None)
@@ -248,7 +239,9 @@ class Task:
             posterior=posterior,
         )
         log_prob_grad_fn, _ = get_log_prob_grad_fn(
-            conditioned_model, implementation=implementation, **kwargs,
+            conditioned_model,
+            implementation=implementation,
+            **kwargs,
         )
 
         def log_prob_grad_pyro(parameters):
@@ -289,7 +282,7 @@ class Task:
             num_observation: Observation number
             observation: Instead of passing an observation number, an observation may be
                 passed directly
-            automatic_transforms_enabled: If True, will automatically construct 
+            automatic_transforms_enabled: If True, will automatically construct
                 transforms to unconstrained space
 
         Returns:
@@ -300,14 +293,14 @@ class Task:
         )
 
         _, transforms = get_log_prob_fn(
-            conditioned_model, automatic_transform_enabled=automatic_transforms_enabled,
+            conditioned_model,
+            automatic_transform_enabled=automatic_transforms_enabled,
         )
 
         return transforms
 
     def _get_observation_seed(self, num_observation: int) -> int:
-        """Get observation seed for a given observation number
-        """
+        """Get observation seed for a given observation number"""
         path = (
             self.path
             / "files"
@@ -372,8 +365,7 @@ class Task:
         raise NotImplementedError
 
     def _save_observation_seed(self, num_observation: int, observation_seed: int):
-        """Save observation seed for a given observation number
-        """
+        """Save observation seed for a given observation number"""
         path = (
             self.path
             / "files"
@@ -387,8 +379,7 @@ class Task:
         ).to_csv(path, index=False)
 
     def _save_observation(self, num_observation: int, observation: torch.Tensor):
-        """Save observed data for a given observation number
-        """
+        """Save observed data for a given observation number"""
         path = (
             self.path
             / "files"
@@ -401,8 +392,7 @@ class Task:
     def _save_reference_posterior_samples(
         self, num_observation: int, reference_posterior_samples: torch.Tensor
     ):
-        """Save reference posterior samples for a given observation number
-        """
+        """Save reference posterior samples for a given observation number"""
         path = (
             self.path
             / "files"
@@ -415,8 +405,7 @@ class Task:
     def _save_true_parameters(
         self, num_observation: int, true_parameters: torch.Tensor
     ):
-        """Save true parameters (parameters that generated the data) for a given observation number
-        """
+        """Save true parameters (parameters that generated the data) for a given observation number"""
         path = (
             self.path
             / "files"
@@ -461,7 +450,8 @@ class Task:
                 num_unique = torch.unique(reference_posterior_samples, dim=0).shape[0]
                 assert num_unique == self.num_reference_posterior_samples
                 self._save_reference_posterior_samples(
-                    num_observation, reference_posterior_samples,
+                    num_observation,
+                    reference_posterior_samples,
                 )
 
         Parallel(n_jobs=n_jobs, verbose=50, backend="loky")(
