@@ -9,10 +9,10 @@ from sbibm.utils.torch import get_default_device
 
 
 def get_float_from_csv(
-    path: Union[str, Path], dtype: type = np.float32,
+    path: Union[str, Path],
+    dtype: type = np.float32,
 ):
-    """Get a single float from a csv file
-    """
+    """Get a single float from a csv file"""
     with open(path, "r") as fh:
         return np.loadtxt(fh).astype(dtype)
 
@@ -38,8 +38,7 @@ def get_results(
 def get_tensor_from_csv(
     path: Union[str, Path], dtype: type = np.float32, atleast_2d: bool = True
 ) -> torch.Tensor:
-    """Get `torch.Tensor` from csv at given path
-    """
+    """Get `torch.Tensor` from csv at given path"""
     device = get_default_device()
 
     if atleast_2d:
@@ -53,8 +52,7 @@ def get_tensor_from_csv(
 def get_ndarray_from_csv(
     path: Union[str, Path], dtype: type = np.float32, atleast_2d: bool = True
 ) -> np.ndarray:
-    """Get `np.ndarray` from csv at given path
-    """
+    """Get `np.ndarray` from csv at given path"""
     if atleast_2d:
         return np.atleast_2d(pd.read_csv(path)).astype(dtype)
     else:
@@ -62,12 +60,15 @@ def get_ndarray_from_csv(
 
 
 def save_float_to_csv(
-    path: Union[str, Path], data: float, dtype: type = np.float32,
+    path: Union[str, Path],
+    data: float,
+    dtype: type = np.float32,
 ):
-    """Save a single float to a csv file
-    """
+    """Save a single float to a csv file"""
     np.savetxt(
-        path, np.asarray(data).reshape(-1).astype(np.float32), delimiter=",",
+        path,
+        np.asarray(data).reshape(-1).astype(np.float32),
+        delimiter=",",
     )
 
 
@@ -78,8 +79,8 @@ def save_tensor_to_csv(
     dtype: type = np.float32,
     index: bool = False,
 ):
-    """Save torch.Tensor to csv at given path
-    """
-    pd.DataFrame(data.cpu().numpy().astype(dtype), columns=columns,).to_csv(
-        path, index=index
-    )
+    """Save torch.Tensor to csv at given path"""
+    pd.DataFrame(
+        data.cpu().numpy().astype(dtype),
+        columns=columns,
+    ).to_csv(path, index=index)
